package org.jboss.system;

import java.beans.PropertyEditorManager;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.util.Properties;
import java.util.logging.Level;
import java.util.logging.Logger;


public class ServiceMBeanSupport implements ServiceMBean {
	private static Logger logger = Logger.getLogger(ServiceMBeanSupport.class.getName());

	static {
		String editorMappings = "java.math.BigDecimal=org.jboss.util.propertyeditor.BigDecimalEditor\n" +
				"java.lang.Boolean=org.jboss.util.propertyeditor.BooleanEditor\n" +
				"java.lang.Class=org.jboss.util.propertyeditor.ClassEditor\n" +
				"java.util.Date=org.jboss.util.propertyeditor.DateEditor\n" +
				"java.io.File=org.jboss.util.propertyeditor.FileEditor\n" +
				"java.net.InetAddress=org.jboss.util.propertyeditor.InetAddressEditor\n" +
				"java.lang.Integer=org.jboss.util.propertyeditor.IntegerEditor\n" +
				"java.util.Properties=org.jboss.util.propertyeditor.PropertiesEditor\n" +
				"java.net.URL=org.jboss.util.propertyeditor.URLEditor";

		try {
			Properties props = new Properties();
			ByteArrayInputStream stream = new ByteArrayInputStream(editorMappings.getBytes());
			props.load(stream);
			for (String key : props.stringPropertyNames()) {
				PropertyEditorManager.registerEditor(Class.forName(key), Class.forName(props.getProperty(key)));
			}
		} catch (Throwable e) {
			throw new IllegalStateException("Unable to register property editors", e);
		}
		logger.info("added bootstrap property editors");
	}

	public void create() throws java.lang.Exception {
		createService();
	}

	protected void createService() throws java.lang.Exception {
	}

	public void start() throws java.lang.Exception {
		startService();
	}

	protected void startService() throws java.lang.Exception {
	}

	public void stop() {
		try {
			stopService();
		} catch (Exception e) {
			logger.log(Level.WARNING, "Exception while stopping service", e);
		}
	}

	protected void stopService() throws java.lang.Exception {
	}

	public void destroy() {
		try {
			destroyService();
		} catch (Exception e) {
			logger.log(Level.WARNING, "Exception while destroying service", e);
		}
	}

	protected void destroyService() throws java.lang.Exception {
	}
}
